@@ -67,11 +67,7 @@ namespace clan
 		}
 
 		/// \brief Constructs a 3x3 matrix (copied)
-		Mat3(const Mat3<Type> &copy)
-		{
-			for (int i = 0; i < 9; i++)
-				matrix[i] = copy.matrix[i];
-		}
+		Mat3(const Mat3<Type> &copy) = default;
 
 		/// \brief Constructs a 3x3 matrix (copied from a 2d matrix)
 		explicit Mat3(const Mat2<Type> &copy);
@@ -312,7 +308,7 @@ namespace clan
 		const Type &operator[](unsigned int i) const { return matrix[i]; }
 
 		/// \brief Copy assignment operator.
-		Mat3<Type> &operator =(const Mat3<Type> &copy) { memcpy(matrix, copy.matrix, sizeof(matrix)); return *this; }
+		Mat3<Type> &operator =(const Mat3<Type> &copy) = default;
 
 		/// \brief Copy assignment operator.
 		Mat3<Type> &operator =(const Mat4<Type> &copy);
