@@ -1,6 +1,6 @@
 /*
 **  ClanLib SDK
-**  Copyright (c) 1997-2015 The ClanLib Team
+**  Copyright (c) 1997-2020 The ClanLib Team
 **
 **  This software is provided 'as-is', without any express or implied
 **  warranty.  In no event will the authors be held liable for any damages
@@ -27,29 +27,26 @@
 **    Kenneth Gangstoe
 */
 
-
 #pragma once
 
-
 namespace clan
 {
-/// \addtogroup clanCore_Math clanCore Math
-/// \{
+	/// \addtogroup clanCore_Math clanCore Math
+	/// \{
 
-/// \brief Alignment origins.
-enum Origin
-{
-	origin_top_left,
-	origin_top_center,
-	origin_top_right,
-	origin_center_left,
-	origin_center,
-	origin_center_right,
-	origin_bottom_left,
-	origin_bottom_center,
-	origin_bottom_right
-};
+	/// \brief Alignment origins.
+	enum class Origin
+	{
+		top_left,
+		top_center,
+		top_right,
+		center_left,
+		center,
+		center_right,
+		bottom_left,
+		bottom_center,
+		bottom_right
+	};
 
+	/// \}
 }
-
-/// \}
