@@ -1,6 +1,6 @@
 /*
 **  ClanLib SDK
-**  Copyright (c) 1997-2015 The ClanLib Team
+**  Copyright (c) 1997-2020 The ClanLib Team
 **
 **  This software is provided 'as-is', without any express or implied
 **  warranty.  In no event will the authors be held liable for any damages
@@ -26,22 +26,19 @@
 **    Magnus Norddahl
 */
 
-
 #pragma once
 
-
 namespace clan
 {
-/// \addtogroup clanSound_Audio_Mixing clanSound Audio Mixing
-/// \{
+	/// \addtogroup clanSound_Audio_Mixing clanSound Audio Mixing
+	/// \{
 
-/// \brief Sound Format Enums
-enum SoundFormat
-{
-	sf_8bit_unsigned,
-	sf_16bit_signed
-};
+	/// \brief Sound Format Enums
+	enum class SoundFormat
+	{
+		sf_8bit_unsigned,
+		sf_16bit_signed
+	};
 
+	/// \}
 }
-
-/// \}
